==> pegasus-merchandise-api-2.2.7-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpProdDynmTitleVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * 动态内容栏目VO
 * Created by ljj on 2017/9/14.
 */
public class OpProdDynmTitleVO implements Serializable{

    /**
     * 栏目id
     */
    private Integer dynmcontId;
    
    /**
     * 是否展开0-展开 1-不展开
     */
    private Integer isOpen;
    
    /**
     * 栏目中文
     */
    private String titleCn;
    
    /**
     * 栏目英文
     */
    private String titleEn;

    /**
     * 栏目详情项集合
     */
    private List<OpProdDynmDetailVO> dynmDtatails;

    /**
     * 栏目排序权重
     */
    private Integer columnSort;

    public Integer getDynmcontId() {
        return dynmcontId;
    }

    public void setDynmcontId(Integer dynmcontId) {
        this.dynmcontId = dynmcontId;
    }

    public List<OpProdDynmDetailVO> getDynmDtatails() {
        return dynmDtatails;
    }

    public void setDynmDtatails(List<OpProdDynmDetailVO> dynmDtatails) {
        this.dynmDtatails = dynmDtatails;
    }

	public Integer getIsOpen() {
		return isOpen;
	}

	public void setIsOpen(Integer isOpen) {
		this.isOpen = isOpen;
	}

	public String getTitleCn() {
		return titleCn;
	}

	public void setTitleCn(String titleCn) {
		this.titleCn = titleCn;
	}

	public String getTitleEn() {
		return titleEn;
	}

	public void setTitleEn(String titleEn) {
		this.titleEn = titleEn;
	}

    public Integer getColumnSort() {
        return columnSort;
    }

    public void setColumnSort(Integer columnSort) {
        this.columnSort = columnSort;
    }
}

==> pegasus-merchandise-api-3.3.2-sources.jar: com/thebeastshop/pegasus/merchandise/vo/OpProdDynmTitleVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * 动态内容栏目VO
 * Created by ljj on 2017/9/14.
 */
public class OpProdDynmTitleVO implements Serializable{

    /**
     * 栏目id
     */
    private Integer dynmcontId;
    
    /**
     * 是否展开0-展开 1-不展开
     */
    private Integer isOpen;
    
    /**
     * 栏目中文
     */
    private String titleCn;
    
    /**
     * 栏目英文
     */
    private String titleEn;

    /**
     * 栏目详情项集合
     */
    private List<OpProdDynmDetailVO> dynmDtatails;

    /**
     * 栏目排序权重
     */
    private Integer columnSort;

    private String clearGap;

    public Integer getDynmcontId() {
        return dynmcontId;
    }

    public void setDynmcontId(Integer dynmcontId) {
        this.dynmcontId = dynmcontId;
    }

    public List<OpProdDynmDetailVO> getDynmDtatails() {
        return dynmDtatails;
    }

    public void setDynmDtatails(List<OpProdDynmDetailVO> dynmDtatails) {
        this.dynmDtatails = dynmDtatails;
    }

	public Integer getIsOpen() {
		return isOpen;
	}

	public void setIsOpen(Integer isOpen) {
		this.isOpen = isOpen;
	}

	public String getTitleCn() {
		return titleCn;
	}

	public void setTitleCn(String titleCn) {
		this.titleCn = titleCn;
	}

	public String getTitleEn() {
		return titleEn;
	}

	public void setTitleEn(String titleEn) {
		this.titleEn = titleEn;
	}

    public Integer getColumnSort() {
        return columnSort;
    }

    public void setColumnSort(Integer columnSort) {
        this.columnSort = columnSort;
    }

    public String getClearGap() {
        return clearGap;
    }

    public void setClearGap(String clearGap) {
        this.clearGap = clearGap;
    }
}
